@@ -1,4 +1,8 @@
 from extras.plugins import PluginTemplateExtension
+from django.conf import settings
+from packaging import version
+
+NETBOX_CURRENT_VERSION = version.parse(settings.VERSION)
 
 
 class SiteTopologyButtons(PluginTemplateExtension):
@@ -8,7 +12,10 @@ class SiteTopologyButtons(PluginTemplateExtension):
     model = 'dcim.site'
 
     def buttons(self):
-        return self.render('nextbox_ui_plugin/site_topo_button.html')
+        if NETBOX_CURRENT_VERSION >= version.parse("3.0"):
+            return self.render('nextbox_ui_plugin/site_topo_button_3.x.html')
+        else:
+            return self.render('nextbox_ui_plugin/site_topo_button.html')
 
 
 # PluginTemplateExtension subclasses must be packaged into an iterable named
